import { Pizza, PlayCircle, Moon } from 'lucide-react';
import GatherResourcesButton from './GatherResourcesButton';
import CollectResourcesButton from './CollectResourcesButton';
import { Pet, Resources } from '../types/Pet';
import { useState, useEffect } from 'react';
import { updatePetAction } from '../services/api/api';
import { PetBasicAction } from '../types/PetUpdateActionRequest';
import ActionButton from './button/ActionButton';

interface InteractionMenuProps {
  pet: Pet;
  onPetUpdate: (updatedPet: Pet) => void;
  onCustomize: () => void;
}

export default function InteractionMenu({ pet, onPetUpdate }: InteractionMenuProps) {
  const [gatheredResources, setGatheredResources] = useState<Resources>({ wisdom: 0, gold: 0, food: 0, junk: 0 });
  const [remainingCooldown, setRemainingCooldown] = useState<number | null>(null);

  useEffect(() => {
    const updateCooldown = () => {
      if (!pet.basicActionCooldown) {
        setRemainingCooldown(null);
        return;
      }

      const cooldownTime = new Date(pet.basicActionCooldown).getTime();
      const now = new Date().getTime();
      const remaining = Math.max(0, cooldownTime - now);

      if (remaining === 0) {
        setRemainingCooldown(null);
      } else {
        setRemainingCooldown(remaining);
      }
    };

    updateCooldown();
    const interval = setInterval(updateCooldown, 1000);
    return () => clearInterval(interval);
  }, [pet.basicActionCooldown]);

  const formatCooldownTime = (ms: number) => {
    const minutes = Math.floor(ms / 60000);
    const seconds = Math.floor((ms % 60000) / 1000);

    if (minutes > 0) {
      return `${minutes} minute${minutes > 1 ? 's' : ''} remaining`;
    }
    return `${seconds} second${seconds > 1 ? 's' : ''} remaining`;
  };

  const handleGatherComplete = (updatedPet: Pet) => {
    onPetUpdate(updatedPet);
  };

  const handleResourcesUpdate = (resources: Resources) => {
    setGatheredResources(resources);
  };

  const handleCollect = () => {
    setGatheredResources({ wisdom: 0, gold: 0, food: 0, junk: 0 });
  };

  function performBasicAction(basicAction: PetBasicAction): () => void {
    return async () => {
      try {
        const updatedPet = await updatePetAction(pet.id, { basicAction: basicAction });
        onPetUpdate(updatedPet);
      } catch (error) {
        console.error('Failed to perform basic action:', error);
      }
    };
  }

  return (
    <div className="grid grid-cols-2 md:grid-cols-3 gap-4">
      {remainingCooldown !== null && (
        <div className="col-span-2 md:col-span-3 text-center p-2 bg-yellow-900/30 border-2 border-yellow-500/50 rounded-lg">
          <span className="text-yellow-200">Cooldown: {formatCooldownTime(remainingCooldown)}</span>
        </div>
      )}

      <ActionButton
        icon={Pizza}
        label="Feed"
        onClick={performBasicAction('FEED')}
        color="green"
        disabled={remainingCooldown !== null}
      />
      <ActionButton
        icon={PlayCircle}
        label="Play"
        onClick={performBasicAction('PLAY')}
        color="blue"
        disabled={remainingCooldown !== null}
      />
      <ActionButton
        icon={Moon}
        label="Sleep"
        onClick={performBasicAction('SLEEP')}
        color="purple"
        disabled={remainingCooldown !== null}
      />

      <div className="col-span-2 md:col-span-3">
        <GatherResourcesButton
          pet={pet}
          onGatherStart={() => console.log('Gathering started')}
          onGatherComplete={handleGatherComplete}
          onResourcesUpdate={handleResourcesUpdate}
        />
        <CollectResourcesButton
          petId={pet.id}
          resources={gatheredResources}
          onCollect={handleCollect}
        />
      </div>
    </div>
  );
}